@@ -1,91 +1,91 @@
 /*!
-* This module provides a set of traits that describes actions that can operate on models. These
-* actions take three major forms; linters, validators, and transformers.
-*
-* 1. **Linters**; these inspect the model for stylistic issues, they are a subset of validators.
-* 1. **Validators**; these inspect models for errors and warnings that may produce errors when the
-*    model is used.
-* 1. **Transformers**; these take in a model and transform it into another model.
-*
-* # Example
-*
-* The following example is taken from the Smithy specification discussing
-* [relative name resolution](https://awslabs.github.io/smithy/1.0/spec/core/shapes.html#relative-shape-id-resolution).
-* The `run_validation_actions` function is commonly used to take a list of actions to be performed
-* on the model in sequence.
-*
-* ```rust
-* use atelier_core::action::validate::{
-*     run_validation_actions, CorrectTypeReferences
-* };
-* use atelier_core::action::Validator;
-* use atelier_core::builder::{
-*     ModelBuilder, ShapeTraits, SimpleShapeBuilder, StructureBuilder, TraitBuilder
-* };
-* use atelier_core::model::Model;
-* use atelier_core::Version;
-* use std::convert::TryInto;
-*
-* let model: Model = ModelBuilder::new(Version::V10, "smithy.example")
-*     .uses("foo.baz#Bar")
-*     .structure(
-*         StructureBuilder::new("MyStructure")
-*             .member("a", "MyString")
-*             .member("b", "smithy.example#MyString")
-*             .member("d", "foo.baz#Bar")
-*             .member("f", "String")
-*             .member("g", "MyBoolean")
-*             .apply_trait(TraitBuilder::new("documentation"))
-*             .into(),
-*     )
-*     .simple_shape(SimpleShapeBuilder::string("MyString"))
-*     .simple_shape(SimpleShapeBuilder::boolean("MyBoolean"))
-*     .try_into().unwrap();
-* let result = run_validation_actions(&mut [
-*         Box::new(CorrectTypeReferences::default()),
-*     ], &model, false);
-* ```
-*
-* This will result in the following list of validation errors. Note that the error is denoted against
-* shape or member identifier accordingly.
-*
-* ```text
-* [
-*     ActionIssue {
-*         reporter: "CorrectTypeReferences",
-*         level: Info,
-*         message: "The simple shape (smithy.example#MyBoolean) is simply a synonym, did you mean to add any constraint traits?",
-*         locus: Some(
-*             ShapeID {
-*                 namespace: NamespaceID(
-*                     "smithy.example",
-*                 ),
-*                 shape_name: Identifier(
-*                     "MyBoolean",
-*                 ),
-*                 member_name: None,
-*             },
-*         ),
-*     },
-*     ActionIssue {
-*         reporter: "CorrectTypeReferences",
-*         level: Info,
-*         message: "The simple shape (smithy.example#MyString) is simply a synonym, did you mean to add any constraint traits?",
-*         locus: Some(
-*             ShapeID {
-*                 namespace: NamespaceID(
-*                     "smithy.example",
-*                 ),
-*                 shape_name: Identifier(
-*                     "MyString",
-*                 ),
-*                 member_name: None,
-*             },
-*         ),
-*     },
-* ]
-* ```
-*
+This module provides a set of traits that describes actions that can operate on models. These
+actions take three major forms; linters, validators, and transformers.
+
+1. **Linters**; these inspect the model for stylistic issues, they are a subset of validators.
+1. **Validators**; these inspect models for errors and warnings that may produce errors when the
+   model is used.
+1. **Transformers**; these take in a model and transform it into another model.
+
+# Example
+
+The following example is taken from the Smithy specification discussing
+[relative name resolution](https://awslabs.github.io/smithy/1.0/spec/core/shapes.html#relative-shape-id-resolution).
+The `run_validation_actions` function is commonly used to take a list of actions to be performed
+on the model in sequence.
+
+```rust
+use atelier_core::action::validate::{
+    run_validation_actions, CorrectTypeReferences
+};
+use atelier_core::action::Validator;
+use atelier_core::builder::{
+    ModelBuilder, ShapeTraits, SimpleShapeBuilder, StructureBuilder, TraitBuilder
+};
+use atelier_core::model::Model;
+use atelier_core::Version;
+use std::convert::TryInto;
+
+let model: Model = ModelBuilder::new(Version::V10, "smithy.example")
+    .uses("foo.baz#Bar")
+    .structure(
+        StructureBuilder::new("MyStructure")
+            .member("a", "MyString")
+            .member("b", "smithy.example#MyString")
+            .member("d", "foo.baz#Bar")
+            .member("f", "String")
+            .member("g", "MyBoolean")
+            .apply_trait(TraitBuilder::new("documentation"))
+            .into(),
+    )
+    .simple_shape(SimpleShapeBuilder::string("MyString"))
+    .simple_shape(SimpleShapeBuilder::boolean("MyBoolean"))
+    .try_into().unwrap();
+let result = run_validation_actions(&mut [
+        Box::new(CorrectTypeReferences::default()),
+    ], &model, false);
+```
+
+This will result in the following list of validation errors. Note that the error is denoted against
+shape or member identifier accordingly.
+
+```text
+[
+    ActionIssue {
+        reporter: "CorrectTypeReferences",
+        level: Info,
+        message: "The simple shape (smithy.example#MyBoolean) is simply a synonym, did you mean to add any constraint traits?",
+        locus: Some(
+            ShapeID {
+                namespace: NamespaceID(
+                    "smithy.example",
+                ),
+                shape_name: Identifier(
+                    "MyBoolean",
+                ),
+                member_name: None,
+            },
+        ),
+    },
+    ActionIssue {
+        reporter: "CorrectTypeReferences",
+        level: Info,
+        message: "The simple shape (smithy.example#MyString) is simply a synonym, did you mean to add any constraint traits?",
+        locus: Some(
+            ShapeID {
+                namespace: NamespaceID(
+                    "smithy.example",
+                ),
+                shape_name: Identifier(
+                    "MyString",
+                ),
+                member_name: None,
+            },
+        ),
+    },
+]
+```
+
 */
 
 use crate::error::Result as ModelResult;
@@ -113,6 +113,9 @@ pub enum IssueLevel {
 /// An issue reported by an action. An issue may, or may not, be associated with a shape but will
 /// always include a message.
 ///
+/// Note that `ActionIssue` also implements `std::error::Error` so it can be used as a failure error
+/// if necessary.
+///
 #[derive(Debug, Clone)]
 pub struct ActionIssue {
     reporter: String,
@@ -174,10 +177,10 @@ pub trait Validator: Action {
 ///
 pub trait Transformer: Action {
     ///
-    /// Transform the input model into another. This _may_ consume the input and produce an entirely
-    /// new model, or it _may_ simply mutate the model and return the modified input.
+    /// Transform the input model into another. The intent of this is **not** to transform a
+    /// model in place but to create a new model from the source.
     ///
-    fn transform(&mut self, model: Model) -> ModelResult<Model>;
+    fn transform(&mut self, source: &Model) -> ModelResult<Model>;
 }
 
 // ------------------------------------------------------------------------------------------------
